@@ -130,6 +130,6 @@ class CRUDBase:
         async with create_session(session) as session:
             obj = await self.get(condition, session)
             if obj is None:
-                obj = await self.create(**defaults)
+                obj = await self.create(**defaults, session=session)
                 created = True
         return obj, created
